@@ -94,7 +94,7 @@ void dbg_outreg32(ScrnInfoPtr,int,int);
 #define MGA_DRIVER_NAME "mga"
 #define MGA_MAJOR_VERSION 1
 #define MGA_MINOR_VERSION 0
-#define MGA_PATCHLEVEL 0
+#define MGA_PATCHLEVEL 1
 
 typedef struct {
     unsigned char	ExtVga[6];
@@ -181,6 +181,11 @@ typedef struct {
 
 #define MGAPTR(p) ((MGAPtr)((p)->driverPrivate))
 
+#define ISDIGITAL1(p) ((p->pMgaHwInfo->ulCapsFirstOutput) & MGAHWINFOCAPS_OUTPUT_DIGITAL)
+#define ISDIGITAL2(p) ((p->pMgaHwInfo->ulCapsSecondOutput) & MGAHWINFOCAPS_OUTPUT_DIGITAL)
+#define ISTV1(p) ((p->pMgaHwInfo->ulCapsFirstOutput) & MGAHWINFOCAPS_OUTPUT_TV)
+#define ISTV2(p) ((p->pMgaHwInfo->ulCapsSecondOutput) & MGAHWINFOCAPS_OUTPUT_TV)
+
 #ifdef DISABLE_VGA_IO
 typedef struct mgaSave {
     pciVideoPtr pvp;
@@ -470,4 +475,26 @@ void CRTC2GetDisplayStart(ScrnInfoPtr pScrn, UnixMODEINFO *pModeInfo, CARD32 bas
  
 double G450SetPLLFreq(ScrnInfoPtr pScrn, long f_out);
 void printDac(ScrnInfoPtr pScrn);
+
+#ifdef USEMGAHAL
+/************ ESC Call Definition ***************/
+typedef struct {
+    char *function;
+    void (*funcptr)(ScrnInfoPtr pScrn, unsigned long *param, char *out, DisplayModePtr pMode);
+} MGAEscFuncRec, *MGAEscFuncPtr;
+
+typedef struct {
+    char function[32];
+    unsigned long parameters[32];
+} EscCmdStruct;
+
+extern LPMGAMODEINFO pMgaModeInfo[2];
+extern MGAMODEINFO   TmpMgaModeInfo[2];
+
+extern void MGAExecuteEscCmd(ScrnInfoPtr pScrn, char *cmdline , char *sResult, DisplayModePtr pMode);
+void FillDisplayModeStruct(DisplayModePtr pMode, LPMGAMODEINFO pModeInfo);
+/************************************************/
 #endif
+
+#endif
+
