@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_dri.c,v 1.14 2000/12/11 22:34:55 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_dri.c,v 1.13 2000/12/01 14:28:57 dawes Exp $ */
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
@@ -379,6 +379,7 @@ Bool MGADRIScreenInit(ScreenPtr pScreen)
    int init_offset;
    int i;
    unsigned long mode_mask;
+   CARD32 pciCommand;
 
    switch(pMGA->Chipset) {
    case PCI_CHIP_MGAG400:
@@ -783,6 +784,11 @@ Bool MGADRIScreenInit(ScreenPtr pScreen)
    }
    xf86DrvMsg(pScrn->scrnIndex, X_INFO, "visual configs initialized\n" );
 
+   /* Enable bus mastering in PCI config space */
+   pciCommand = pciReadLong(pMGA->PciTag, PCI_CMD_STAT_REG);
+   pciWriteLong(pMGA->PciTag, PCI_CMD_STAT_REG,
+		pciCommand | PCI_CMD_MASTER_ENABLE);
+
    return TRUE;
 }
 
